require_relative "boot"

require "rails"
# Pick the frameworks you want:
require "active_model/railtie"
require "active_job/railtie"
require "active_record/railtie"
# require "active_storage/engine"
require "action_controller/railtie"
require "action_mailer/railtie"
require "action_mailbox/engine"
# require "action_text/engine"
require "action_view/railtie"
# require "action_cable/engine"
# require "rails/test_unit/railtie"

# Require the gems listed in Gemfile, including any gems
# you've limited to :test, :development, or :production.
Bundler.require(*Rails.groups)

module DataCollector
  class Application < Rails::Application
    # Initialize configuration defaults for originally generated Rails version.
    config.load_defaults 7.2

    # Please, add to the `ignore` list any other `lib` subdirectories that do
    # not contain `.rb` files, or that should not be reloaded or eager loaded.
    # Common ones are `templates`, `generators`, or `middleware`, for example.
    config.autoload_lib(ignore: %w[assets tasks])

    # it's strongly discouraged using add_autoload_paths_to_load_path, but rack_attack initializer can't load config files without it
    config.add_autoload_paths_to_load_path = true
    
    # Configuration for the application, engines, and railties goes here.
    #
    # These settings can be overridden in specific environments using the files
    # in config/environments, which are processed later.
    #
    config.time_zone = "London"
    # config.eager_load_paths << Rails.root.join("extras")

    # Don't generate system test files.
    config.generators.system_tests = nil
    config.exceptions_app = routes

    config.active_job.queue_adapter = :sidekiq

    config.session_store(
      :cookie_store,
      key: "_data_collector_session",
      secure: (Rails.env.production? || Rails.env.staging? || Rails.env.review?)
    )

    config.generators do |g|
      g.test_framework :rspec,
                       request_specs: true,
                       view_specs: false,
                       routing_specs: false,
                       helper_specs: false,
                       controller_specs: false
    end

    config.relative_url_root = ENV["RAILS_RELATIVE_URL_ROOT"]
  end
end
